@@ -1040,7 +1040,7 @@ WidgetFactory.moveChildren = function(sourceWidget, targetWidget, settingsGroup)
 
     // move child widgets of UI file based widget directly to
     // options toolbar. rendering of tool buttons greatly depends
-    // on this (especially on Mac OS X):
+    // on this (especially on macOS):
     var children = sourceWidget.children();
     for(var i=0;i<children.length;++i) {
         var w=children[i];
@@ -1315,6 +1315,88 @@ WidgetFactory.initVAlignCombo = function(comboBox) {
     comboBox.addItem(qsTr("Bottom"), RS.VAlignBottom);
 };
 
+WidgetFactory.initDimlunitCombo = function(comboBox) {
+    comboBox.clear();
+    comboBox.addItem(qsTr("Scientific"), RS.Scientific);
+    comboBox.addItem(qsTr("Decimal"), RS.Decimal);
+    comboBox.addItem(qsTr("Engineering"), RS.Engineering);
+    comboBox.addItem(qsTr("Architectural"), RS.ArchitecturalStacked);
+    comboBox.addItem(qsTr("Fractional"), RS.FractionalStacked);
+};
+
+WidgetFactory.initDimtadCombo = function(comboBox) {
+    comboBox.clear();
+    comboBox.addItem(qsTr("Centered"), 0);
+    comboBox.addItem(qsTr("Above"), 1);
+};
+
+WidgetFactory.initDimdsepCombo = function(comboBox) {
+    comboBox.clear();
+    comboBox.addItem(".", '.');
+    comboBox.addItem(",", ',');
+};
+
+WidgetFactory.initDimzinCombo = function(comboBox) {
+    comboBox.clear();
+    //comboBox.addItem(qsTr("Suppress 0'0\" (unsupported)"), 0);
+    comboBox.addItem(qsTr("Show trailing zeroes"), 0);
+    comboBox.addItem(qsTr("Include 0'0\"") + " " + qsTr("(unsupported)"), 1);
+    comboBox.addItem(qsTr("Include 0', suppress 0\"") + " " + qsTr("(unsupported)"), 2);
+    comboBox.addItem(qsTr("Include 0\", suppress 0'") + " " + qsTr("(unsupported)"), 3);
+    comboBox.addItem(qsTr("Suppress leading zeroes") + " " + qsTr("(unsupported)"), 4);
+    comboBox.addItem(qsTr("Suppress trailing zeroes"), 8);
+    comboBox.addItem(qsTr("Suppress leading / trailing zeroes") + " " + qsTr("(unsupported)"), 12);
+
+//    comboBox.addItem(qsTr("Suppress 0'0\""), 0);
+//    comboBox.addItem(qsTr("Include 0'0\""), 1);
+//    comboBox.addItem(qsTr("Include 0', suppress 0\""), 2);
+//    comboBox.addItem(qsTr("Include 0\", suppress 0'"), 3);
+};
+
+WidgetFactory.initDimdecCombo = function(comboBox) {
+    comboBox.clear();
+    comboBox.addItem("0", 0);
+    comboBox.addItem("1", 1);
+    comboBox.addItem("2", 2);
+    comboBox.addItem("3", 3);
+    comboBox.addItem("4", 4);
+    comboBox.addItem("5", 5);
+    comboBox.addItem("6", 6);
+    comboBox.addItem("7", 7);
+    comboBox.addItem("8", 8);
+
+};
+WidgetFactory.initDimaunitCombo = function(comboBox) {
+    comboBox.clear();
+    comboBox.addItem(qsTr("Decimal Degrees"), RS.DegreesDecimal);
+    comboBox.addItem(qsTr("Deg/min/sec"), RS.DegreesMinutesSeconds);
+    comboBox.addItem(qsTr("Gradians"), RS.Gradians);
+    comboBox.addItem(qsTr("Radians"), RS.Radians);
+    comboBox.addItem(qsTr("Surveyor's units"), RS.Surveyors);
+};
+
+WidgetFactory.initDimazinCombo = function(comboBox) {
+    comboBox.clear();
+    comboBox.addItem(qsTr("Show trailing zeroes"), 0);
+    comboBox.addItem(qsTr("Suppress leading zeroes") + " " + qsTr("(unsupported)"), 1);
+    comboBox.addItem(qsTr("Suppress trailing zeroes"), 2);
+    comboBox.addItem(qsTr("Suppress leading / trailing zeroes") + " " + qsTr("(unsupported)"), 3);
+};
+
+WidgetFactory.initDimadecCombo = function(comboBox) {
+    comboBox.clear();
+    comboBox.addItem("0", 0);
+    comboBox.addItem("1", 1);
+    comboBox.addItem("2", 2);
+    comboBox.addItem("3", 3);
+    comboBox.addItem("4", 4);
+    comboBox.addItem("5", 5);
+    comboBox.addItem("6", 6);
+    comboBox.addItem("7", 7);
+    comboBox.addItem("8", 8);
+};
+
+
 WidgetFactory.initOrientationCombo = function(comboBox) {
     comboBox.clear();
 
